Method: FMOD::ChannelGroup#subgroup_count

Defined in:
lib/fmod/channel_group.rb

#subgroup_countInteger (readonly)

Returns the number of sub groups under this channel group.

Returns:

  • (Integer)

    the number of sub groups under this channel group.



13
# File 'lib/fmod/channel_group.rb', line 13

integer_reader(:subgroup_count, :ChannelGroup_GetNumGroups)