Method: FMOD::Dsp#show_dialog

Defined in:
lib/fmod/dsp.rb

#show_dialog(hwnd, show = true) ⇒ void

This method returns an undefined value.

Display or hide a DSP unit configuration dialog box inside the target window.

Parameters:

  • hwnd (Pointer)

    Target HWND in windows to display configuration dialog.

  • show (Boolean) (defaults to: true)

    true to display the window within the parent window, otherwise false to remove it.



391
392
393
# File 'lib/fmod/dsp.rb', line 391

def show_dialog(hwnd, show = true)
  FMOD.invoke(:DSP_ShowConfigDialog, self, hwnd, show.to_i)
end