Method: FMOD::Effects::ConvolutionReverb#ir=

Defined in:
lib/fmod/effects/convolution_reverb.rb

#ir=(value) ⇒ Pointer|String (writeonly)

Array of signed 16-bit (short) PCM data to be used as reverb IR. First member of the array should be a 16-bit value (short) which specifies the number of channels. Array looks like [index 0 = channel_count][index 1+ = raw 16-bit PCM data].

Data is copied internally so source can be freed.

Parameters:

  • value (Pointer|String)

    the value to set the attribute ir to.

Returns:

  • (Pointer|String)

    the newly set value



24
25
26
# File 'lib/fmod/effects/convolution_reverb.rb', line 24

def ir=(value)
  @ir = value
end